==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/RepositoryEJB/src/com/clustercontrol/repository/bean/FacilityAttributeConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.bean;

/**
 * Facility(BMP Entity Bean)°̾饹
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class FacilityAttributeConstant {
	public static final String FACILITYID = "ccFacilityId";
	public static final String CN = "cn";
	public static final String DESCRIPTION = "description";
	public static final String PINGWATCH = "ccPingWatch";
	public static final String PINGWATCHSTATUS = "ccPingWatchStatus";
	public static final String AGENTWATCH = "ccAgentWatch";
	public static final String AGENTWATCHSTATUS = "ccAgentWatchStatus";
	public static final String STATUSWATCH = "ccStatusWatch";
	public static final String LOGWATCH = "ccLogWatch";
	public static final String AGENTCONTROL = "ccAgentControl";
	public static final String DHCPCLIENT = "ccDhcpClient";
	public static final String IPTYPE = "ccIpType";
	public static final String IPPROTOCOLNUMBER = "ipProtocolNumber";
	public static final String IPNETWORKNUMBER = "ipNetworkNumber";
	public static final String IPNETWORKNUMBERV6 = "ccIpNetworkNumberV6";
	public static final String HOST = "host";
	public static final String MACHINE = "ccMachine";
	public static final String PLATFORM = "ccPlatform";
	public static final String OSNAME = "ccOsName";
	public static final String NODENAME = "ccNodeName";
	public static final String OSRELEASE = "ccOsRelease";
	public static final String OSVERSION = "ccOsVersion";
	public static final String CHARSET = "ccCharSet";
	public static final String MANAGERNAME = "ccManagerName";
	public static final String MANAGERCONTACT = "ccManagerContact";
	public static final String CREATORSNAME = "ccCreatorsName";
	public static final String CREATETIMESTAMP = "ccCreateTimestamp";
	public static final String MODIFIERSNAME = "ccModifiersName";
	public static final String MODIFYTIMESTAMP = "ccModifyTimestamp";
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/RepositoryEJB/src/com/clustercontrol/repository/bean/FacilityAttributeConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.bean;

/**
 * Facility(BMP Entity Bean)の属性名定義クラス
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class FacilityAttributeConstant {
	public static final String FACILITYID = "ccFacilityId";
	public static final String CN = "cn";
	public static final String DESCRIPTION = "description";
	public static final String PINGWATCH = "ccPingWatch";
	public static final String PINGWATCHSTATUS = "ccPingWatchStatus";
	public static final String AGENTWATCH = "ccAgentWatch";
	public static final String AGENTWATCHSTATUS = "ccAgentWatchStatus";
	public static final String STATUSWATCH = "ccStatusWatch";
	public static final String LOGWATCH = "ccLogWatch";
	public static final String AGENTCONTROL = "ccAgentControl";
	public static final String DHCPCLIENT = "ccDhcpClient";
	public static final String IPTYPE = "ccIpType";
	public static final String IPPROTOCOLNUMBER = "ipProtocolNumber";
	public static final String IPNETWORKNUMBER = "ipNetworkNumber";
	public static final String IPNETWORKNUMBERV6 = "ccIpNetworkNumberV6";
	public static final String HOST = "host";
	public static final String MACHINE = "ccMachine";
	public static final String PLATFORM = "ccPlatform";
	public static final String OSNAME = "ccOsName";
	public static final String NODENAME = "ccNodeName";
	public static final String OSRELEASE = "ccOsRelease";
	public static final String OSVERSION = "ccOsVersion";
	public static final String CHARSET = "ccCharSet";
	public static final String MANAGERNAME = "ccManagerName";
	public static final String MANAGERCONTACT = "ccManagerContact";
	public static final String CREATORSNAME = "ccCreatorsName";
	public static final String CREATETIMESTAMP = "ccCreateTimestamp";
	public static final String MODIFIERSNAME = "ccModifiersName";
	public static final String MODIFYTIMESTAMP = "ccModifyTimestamp";
}
